# Library Name

Am async test suite for testing PLC System G3 programs.

## Installation

The installation can be done with the package manager `pip`.

```bash
pip install g3tester
```

## Usage

See the `examples` directory.


